# Alchimie Data Solutions : adsToolBox

`adsToolBox` est une librairie Python conçue pour regrouper toutes les fonctions génériques qui peuvent être utilisées au
cours des développements liés à **Onyx**. Elle fournit un ensemble d'outils robustes pour :

- **Gérer des connexions** à des bases de données PostgreSQL et SQL Server.
- **Créer et gérer des pipelines** de données entre bases, ou encore de tableau vers base.
- **Chronométrer les échanges de données** pour le suivi des performances.
- **Journaliser les évènements** en console, en fichier et en base de données.
- **Gérer l'environnement** via des fichiers `.env`.

## Installation

Vous pouvez installer la librairie directement depuis PyPI en utilisant `pip` :
```bash
pip install adsToolBox
```

## Utilisation

Des exemple d'utilisation sont disponibles sur ce repo github : [Démo](https://github.com/AlchimieDataSolutions/DemoPy).

## Documentation

Pour en savoir plus sur ce que fait chaque fonctionnalité du projet, voici le repo du projet 
[adsToolBox](https://github.com/AlchimieDataSolutions/adsGenericFunctions).

## Dépendances

Les dépendances sont dans le fichier requirements.txt.
